@@ -106,8 +106,20 @@ class TestTopParsing:
         OM      O         1    1.9670816e-03  8.5679450e-07
         """,
         "types",
-        {"bonds": {("OM", "O"): (["1", "1.9670816e-03", "8.5679450e-07"], None)}}
+        {"bonds": {("OM", "O"): [(["1", "1.9670816e-03", "8.5679450e-07"], None)]}}
          ),
+        ("""
+        [ dihedraltypes ]
+        CEL1    CEL1    CTL2    CTL2     9  1.800000e+02  3.807440e+00      1
+        CEL1    CEL1    CTL2    CTL2     9  1.800000e+02  7.531200e-01      2
+        CEL1    CEL1    CTL2    CTL2     9  1.800000e+02  7.112800e-01      3
+        """,
+        "types",
+        {"dihedrals": {("CEL1", "CEL1", "CTL2", "CTL2"): [(["9", "1.800000e+02", "3.807440e+00", "1"], None),
+                                                          (["9", "1.800000e+02", "7.531200e-01", "2"], None),
+                                                          (["9", "1.800000e+02", "7.112800e-01", "3"], None)]}}
+        ),
+
         ("""
         [ system ]
         some multiline
